@@ -128,6 +128,9 @@ sub run_tcp_server {
                         }
                         else {
                             STOP and talk INFO, "tls started ok";
+                            STOP
+                              and talk INFO, "cipher: "
+                              . Net::SSLeay::get_cipher( $handle->{tls} );
                         }
                     }
                 },
@@ -255,18 +258,32 @@ sub create_tls {
 
     eval {
         $tls = AnyEvent::TLS->new(
-            method    => 'tlsv1',
             cert_file => $self->{tls_crt},
             key_file  => $self->{tls_key},
         );
 
-        # NPN  (Net-SSLeay > 1.45, openssl >= 1.0.1)
-        Net::SSLeay::CTX_set_next_protos_advertised_cb( $tls->ctx,
-            [Protocol::HTTP2::ident_tls] );
+        # ECDH curve ( Net-SSLeay >= 1.56, openssl >= 1.0.0 )
+        if ( exists &Net::SSLeay::CTX_set_tmp_ecdh ) {
+            my $curve = Net::SSLeay::OBJ_txt2nid('prime256v1');
+            my $ecdh  = Net::SSLeay::EC_KEY_new_by_curve_name($curve);
+            Net::SSLeay::CTX_set_tmp_ecdh( $tls->ctx, $ecdh );
+            Net::SSLeay::EC_KEY_free($ecdh);
+        }
 
         # ALPN (Net-SSLeay > 1.55, openssl >= 1.0.2)
-        #Net::SSLeay::CTX_set_alpn_select_cb( $ctx,
-        #    [ Protocol::HTTP2::ident_tls ] );
+        if ( exists &Net::SSLeay::CTX_set_alpn_select_cb ) {
+            Net::SSLeay::CTX_set_alpn_select_cb( $tls->ctx,
+                [Protocol::HTTP2::ident_tls] );
+        }
+
+        # NPN  (Net-SSLeay > 1.45, openssl >= 1.0.1)
+        elsif ( exists &Net::SSLeay::CTX_set_next_protos_advertised_cb ) {
+            Net::SSLeay::CTX_set_next_protos_advertised_cb( $tls->ctx,
+                [Protocol::HTTP2::ident_tls] );
+        }
+        else {
+            die "ALPN and NPN is not supported\n";
+        }
     };
 
     $self->finish("Some problem with TLS: $@\n") if $@;
